@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: BibTeX.py,v 1.21.2.2 2000/10/09 07:27:58 fredgo Exp $
+# $Id: BibTeX.py,v 1.21.2.4 2001/11/28 18:07:32 fredgo Exp $
 
 # Extension module for BibTeX files
 
@@ -163,12 +163,14 @@ class Entry (Base.Entry):
         if isinstance (value, Date): return
         
         # then, convert as bibtex.
+        quote = 1
         if isinstance (value, Reference):
             value = string.join (map (lambda item: item.key, value.list), ', ')
-        
+            quote = 0
+            
 	self.dict [key] = _bibtex.reverse (_fieldtype (Types.get_field (key)),
                                            Config.get ('bibtex+/braces').data,
-                                           value)
+                                           value, quote)
 	return
 
 
@@ -347,7 +349,7 @@ class DataBase (Base.DataBase):
 		_bibtex.set_string (self.parser, k,
 				    _bibtex.reverse (_base_fieldtype [Text],
                                                      Config.get ('bibtex+/braces').data,
-						     user [k] [0]))
+						     user [k] [0], 0))
 
 	finished = 0
 	errors = []
@@ -405,7 +407,7 @@ class DataBase (Base.DataBase):
 		_bibtex.set_string (self.parser, k,
 				    _bibtex.reverse (_base_fieldtype [Text],
                                                      Config.get ('bibtex+/braces').data,
-						     user [k] [0]))
+						     user [k] [0], 0))
 	return
 
 
@@ -452,7 +454,7 @@ def _nativify (field, fieldtype):
     ''' private method to convert from field to native format '''
 
     obj = _bibtex.reverse (fieldtype, Config.get ('bibtex+/braces').data,
-                           field)
+                           field, 1)
     return _bibtex.get_native (obj)
 
 
@@ -595,6 +597,10 @@ def writer (it, output):
 
 	    output.write ('\n')
 
+    # write the crossreferenced ones
+    for entry in refere.values ():
+        entry_write (entry, output)
+    
     # write the entries with no cross references
     entry = it.first ()
     while entry:
@@ -602,10 +608,6 @@ def writer (it, output):
             entry_write (entry, output)
 	entry = it.next ()
 
-    # write the crossreferenced ones
-    for entry in refere.values ():
-        entry_write (entry, output)
-    
     return
 
 
