@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Document.py,v 1.18.2.9 2000/11/13 09:35:25 fredgo Exp $
+# $Id: Document.py,v 1.18.2.13 2001/11/29 09:09:00 fredgo Exp $
 
 ''' This module defines a Document class '''
 
@@ -32,7 +32,7 @@ from Pyblio.GnomeUI.Config import ConfigDialog
 from Pyblio.GnomeUI.Fields import FieldsDialog, EntriesDialog
 
 from Pyblio import Connector, Open, Exceptions, Selection, Sort, Base, Config
-from Pyblio import version, Fields, Types
+from Pyblio import version, Fields, Types, Query
 
 import Pyblio.Style.Utils
 
@@ -52,6 +52,7 @@ class Document (Connector.Publisher):
             UIINFO_MENU_NEW_ITEM     (_("_New"), None, self.new_document),
             UIINFO_MENU_OPEN_ITEM    (self.ui_open_document),
             UIINFO_ITEM              (_("_Merge with..."),None, self.merge_database),
+            UIINFO_ITEM              (_("Medline Query..."),None, self.query_database),
             UIINFO_MENU_SAVE_ITEM    (self.save_document),
             UIINFO_MENU_SAVE_AS_ITEM (self.save_document_as),
             UIINFO_SEPARATOR,
@@ -108,7 +109,7 @@ class Document (Connector.Publisher):
             UIINFO_ITEM_STOCK(_("Save"),  None, self.save_document,    STOCK_PIXMAP_SAVE),
             UIINFO_SEPARATOR,
             UIINFO_ITEM_STOCK(_("Find"),  None, self.find_entries,     STOCK_PIXMAP_SEARCH),
-            UIINFO_ITEM_STOCK(_("Cite"), None, self.lyx_cite,          STOCK_MENU_CONVERT),
+            UIINFO_ITEM_STOCK(_("Cite"),  None, self.lyx_cite,          STOCK_MENU_CONVERT),
             UIINFO_SEPARATOR,
             UIINFO_ITEM_STOCK(_("Close"), None, self.close_document,   STOCK_PIXMAP_CLOSE),
             ]
@@ -310,6 +311,40 @@ class Document (Connector.Publisher):
         return
 
 
+    def query_database (self, * arg):
+        ''' callback corresponding to the "Query..." button '''
+
+        if not self.confirm (): return
+
+        def dlg_cb_2 (dummy): return
+        
+        dlg = GnomeOkCancelDialog (_("Enter your Medline query"), dlg_cb_2, self.w)
+        
+        key_w = GtkEntry()
+        adj   = GtkAdjustment (100, 0, 10000, 1.0, 100.0, 0.0)
+        max_w = GtkSpinButton (adj=adj, digits=0)
+
+        dlg.vbox.pack_start (GtkLabel (_("Search string")))
+        dlg.vbox.pack_start (key_w)
+        key_w.set_editable (TRUE)
+        
+        dlg.vbox.pack_start (GtkLabel (_("Maximum number of results")))
+        dlg.vbox.pack_start (max_w)
+        
+        dlg.show_all ()
+        dlg.run_and_close ()
+        
+        keyword  = string.strip (key_w.get_text ())
+        maxcount = max_w.get_value_as_int ()
+        
+        if keyword == "": return
+        
+        url = Query.medline_query (keyword, maxcount)
+        
+        self.open_document (url, 'medline', no_name = TRUE)
+        return
+
+
     def merge_database (self, * arg):
         ''' add all the entries of another database to the current one '''
         # get a new file name
@@ -373,7 +408,7 @@ class Document (Connector.Publisher):
         return
 
     
-    def open_document (self, url, how = None):
+    def open_document (self, url, how = None, no_name = FALSE):
         
         Utils.set_cursor (self.w, 'clock')
         
@@ -390,6 +425,8 @@ class Document (Connector.Publisher):
             return
 
         Utils.set_cursor (self.w, 'normal')
+
+        if no_name: data.key = None
         
         self.data    = data
         self.redisplay_index (0)
@@ -465,22 +502,20 @@ class Document (Connector.Publisher):
                        out = file, how = how)
         file.close ()
         
-        if self.data.key is None:
-            # we wrote an anonymous database. Lets reopen it !
-            try:
-                self.data = Open.bibopen (url, how = how)
+        try:
+            self.data = Open.bibopen (url, how = how)
                 
-            except (Exceptions.ParserError,
-                    Exceptions.FormatError,
-                    Exceptions.FileError), error:
+        except (Exceptions.ParserError,
+                Exceptions.FormatError,
+                Exceptions.FileError), error:
                     
-                Utils.set_cursor (self.w, 'normal')
-                Utils.error_dialog (_("Reopen error"), error,
-                                    parent = self.w)
-                return
+            Utils.set_cursor (self.w, 'normal')
+            Utils.error_dialog (_("Reopen error"), error,
+                                parent = self.w)
+            return
             
-            self.redisplay_index ()
-            self.issue ('open-document', self)
+        self.redisplay_index ()
+        self.issue ('open-document', self)
             
         Utils.set_cursor (self.w, 'normal')
 
