@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Index.py,v 1.11.2.3 2000/07/24 09:39:32 fredgo Exp $
+# $Id: Index.py,v 1.11.2.6 2001/10/24 16:56:55 fredgo Exp $
 
 ''' Main index containing the columned view of the entries '''
 
@@ -146,7 +146,15 @@ class Index (Connector.Publisher):
         if info == Mime.ENTRY:
             text = pickle.dumps (self.selection_buffer)
         else:
-            text = join (map (str, self.selection_buffer), '\n\n')
+            if Config.get ('gnome/paste-key').data:
+                # if we want the keys, return the keys !
+                keys = []
+                for e in self.selection_buffer:
+                    keys.append (str (e.key.key))
+                text = join (keys, ',')
+            else:
+                # else, return the full entries
+                text = join (map (str, self.selection_buffer), '\n\n')
         
         selection.set (1, 8, text)
         return
@@ -255,7 +263,13 @@ class Index (Connector.Publisher):
             row = []
             
             for f in self.fields:
-                if entry.has_key (f):
+                if f == '-key-':
+                    row.append (str (entry.key.key))
+                    
+                elif f == '-type-':
+                    row.append (str (entry.type.name))
+                    
+                elif entry.has_key (f):
                     
                     if Types.get_field (f).type == Fields.AuthorGroup:
                         text = join (map (lambda a: str (a.last), entry [f]), ', ')
@@ -380,5 +394,4 @@ class Index (Connector.Publisher):
         for i in range (len (self.fields)):
             config.set_int ('Pybliographic/Columns/%s' % self.fields [i],
                             self.field_width [i])
-
         return
